AiutaFeatures constructor
- AiutaWelcomeScreenFeature? welcomeScreen,
- AiutaOnboardingFeature? onboarding,
- AiutaConsentFeature? consent,
- required AiutaImagePickerFeature imagePicker,
- required AiutaTryOnFeature tryOn,
- AiutaWishlistFeature? wishlist,
Creates an AiutaFeatures instance with the given features configurations.
The welcomeScreen is the optional and is shown before the onboarding
unless the onboarding is not completed.
The onboarding is the optional, which is used to show the user how the virtual
try-on works.
Required imagePicker for the currently main screen, which allows users to select images
to be used for virtual try-on.
Required tryOn is the main feature for the virtual try-on functionality.
The consent describes the consent feature, which can be embedded into
the onboarding pages or displayed as a standalone page.
The share is the optional feature that adds the ability to share generated images.
The wishlist is the optional feature to interact with the host application's wishlist.
Implementation
AiutaFeatures({
this.welcomeScreen,
this.onboarding,
this.consent,
required this.imagePicker,
required this.tryOn,
this.share,
this.wishlist,
});