AiutaInputImage class

General image model of any history flows

Annotations
  • @JsonSerializable.new()

Constructors

AiutaInputImage({required String id, required String url, required AiutaOwnerType ownerType})
Creates an AiutaInputImage with the given unique id and url path, ownerType of the image defines the way how the image should be stored and removed from the users' history.
AiutaInputImage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
ID of the uploaded image.
final
ownerType AiutaOwnerType
Type of the image owner.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
URL of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited